<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_html', language 'id', version '5.0'.
 *
 * @package     block_html
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['allowadditionalcssclasses'] = 'Izinkan kelas CSS tambahan';
$string['configallowadditionalcssclasses'] = 'Menambahkan opsi konfigurasi ke model blok HTML yang memungkinkan kelas CSS tambahan untuk disetel.';
$string['configclasses'] = 'Kelas CSS tambahan';
$string['configclasses_help'] = 'Tujuan konfigurasi ini adalah untuk membantu tema dengan membantu membedakan blok teks satu sama lain. Setiap kelas CSS yang dimasukkan di sini (dibatasi spasi) akan ditambahkan ke kelas bawaan blok.';
$string['configcontent'] = 'Konten';
$string['configtitle'] = 'Judul blok teks';
$string['html:addinstance'] = 'Tambahkan blok HTML';
$string['html:myaddinstance'] = 'Tambahkan blok HTML ke Dasbor';
$string['newhtmlblock'] = '(blok HTML baru)';
$string['pluginname'] = 'Teks';
$string['privacy:metadata:block'] = 'Blok Teks menyimpan semua datanya di dalam subsistem blok.';
$string['search:content'] = 'konten blok HTML';
